import { Component, OnInit, Input, OnDestroy } from '@angular/core';
import { Exercise, IExerciseType } from 'app/shared/model/exercise.model';
import { Person } from 'app/shared/model/person.model';
import { Subscription } from 'rxjs';
import { PluginActionInfo } from 'app/shared/model/search/search-result-dto.model';
import { PluginService } from 'app/shared/service/plugin-service';
import { ShoppingBasketInfo, ShoppingBasketRedirectInfoDTO } from 'app/shared/model/basket/shopping-basket-info.model';

import { AccountService } from 'app/core/auth/account.service';
import { Account } from 'app/core/user/account.model';
@Component({
    selector: 'jhi-exercise-details',
    templateUrl: './exercise-details.component.html',
    styleUrls: ['./exercise-details.component.scss'],
})
export class ExerciseDetailsComponent implements OnInit, OnDestroy {
    @Input() exercise: Exercise | undefined;
    account: Account | null = null;
    authSubscription?: Subscription;

    constructor(private accountService: AccountService, protected pluginService: PluginService) { }

    ngOnInit(): void {
        this.authSubscription = this.accountService.getAuthenticationState().subscribe(account => (this.account = account));
    }

    public get exerciseType(): typeof IExerciseType {
        return IExerciseType;
    }

    public isAuthenticated(): boolean {
        return this.accountService.isAuthenticated();
    }

    public getPersonName(person: Person): string {
        return person.name;
    }

    public getPersonDetails(person: Person): string {
        return person.name + ', ' + person.affiliation;
    }

    public getPersonDetailsWithEmail(person: Person): string {
        return "<a class='text-dark' href= 'mailto:'" + person.email + '>' + person.name + ', ' + person.affiliation + '</a>';
    }

    public arrayToString(array: string[]): string {
        let result = '';
        let i = 1;
        array.forEach(element => {
            if (array.length > 1 && array.length !== i) {
                result += element + ', ';
            } else {
                result += element;
            }
            if (i % 5 === 0) {
                result += '<br>';
            }
            i++;
        });
        return result;
    }

    public startAction(action: PluginActionInfo, exercise: Exercise): void {
        const basketInfo: ShoppingBasketInfo = {
            plugin: action.plugin,
            action: action.action,
            itemInfos: [
                exercise.originalResult
            ]
        };
        this.pluginService.getRedirectLink(basketInfo).subscribe(
            (redirectInfo: ShoppingBasketRedirectInfoDTO) => {
                // alert('redirecting to ' + redirectInfo.redirectURL);
                location.href = redirectInfo.redirectURL;
                //				window.open(redirectInfo.redirectURL/* , action.plugin */);
            },
            () => alert('Search failed'))
    }

    openLink(link: string): void {
        window.open(link);
    }

    ngOnDestroy(): void {
        if (this.authSubscription) {
            this.authSubscription.unsubscribe();
        }
    }
}
